@@ -20,7 +20,21 @@ ibft_get_att() {
 }
 
 ibft_get_ethdev() {
-    (cd $ibft_nic/device/net; ls -d eth* 2>/dev/null)
+    local iface
+
+    if test -d "$ibft_nic/device/net" ; then
+	for iface in $ibft_nic/device/net/*/addr_len; do
+	    break
+        done
+    else
+	for iface in $ibft_nic/device/*/*/addr_len; do
+            break
+	done
+    fi
+    iface=${iface%/*}
+    iface=${iface##*/}
+
+    echo "$iface"
 }
 
 ibft_get_initiatorname() {
