@@ -20,6 +20,12 @@ fi
 
 verbose "[MOUNT] Root:\t$rootdev"
 
+usrfsck="/sbin/fsck.${usrfstype}"
+if [ ! -x "$usrfsck" ]; then
+   # just ignore it - we'll see later what happens
+   usrfsck=
+fi
+
 for file in {/usr,}/bin/on_ac_power; do
     if test -e $file; then
         cp_bin $file $tmp_mnt/usr/bin
@@ -29,3 +35,4 @@ done
 
 save_var rootdev
 save_var rootfsck
+save_var usrfsck
