@@ -1,7 +1,7 @@
 #!/bin/sh
 #findlang - automagically generate list of language specific files
 #for inclusion in an rpm spec file.
-#This does assume that the *.mo files are under .../share/locale/...
+#This does assume that the *.mo files are under .../locale/...
 #Run with no arguments gets a usage message.
 
 #findlang is copyright (c) 1998 by W. L. Estes <wlestes@uncg.edu>
@@ -116,7 +116,7 @@ while test $# -gt 0 ; do
 done    
 
 if ! test -s $MO_NAME ; then
-    echo "%defattr (644, root, root, 755)" > $MO_NAME
+	echo "%defattr (644, root, root, 755)" > $MO_NAME
 fi
 
 MO_NAME_NEW=$MO_NAME.tmp.$$
@@ -132,25 +132,32 @@ find $TOP_DIR/usr/share/locale/ -maxdepth 1 -type d | sed 's:'"$TOP_DIR"/usr/sha
     rm -rf $TOP_DIR/usr/share/locale/$dir
   fi
 done
+find $TOP_DIR/usr/share/help/ -maxdepth 1 -type d | sed 's:'"$TOP_DIR"/usr/share/help/'::; /^$/d' | while read dir; do
+  if ! rpm -ql filesystem | egrep -q "/usr/share/help/$dir"$; then
+    echo "removing help translation /usr/share/help/$dir"
+    rm -rf $TOP_DIR/usr/share/help/$dir
+  fi
+done
 
 find $TOP_DIR -type f -o -type l|sed '
 s:'"$TOP_DIR"'::
-'"$ALL_NAME$MO"'s:\(.*/share/locale/\)\([^/_]\+\)\(.*\.mo$\):%lang(\2) \1\2\3:
-'"$NO_ALL_NAME$MO"'s:\(.*/share/locale/\)\([^/_]\+\)\(.*/'"$NAME"'\.mo$\):%lang(\2) \1\2\3:
+'"$ALL_NAME$MO"'s:\(.*/locale/\)\([^/_]\+\)\(.*\.mo$\):%lang(\2) \1\2\3:
+'"$NO_ALL_NAME$MO"'s:\(.*/locale/\)\([^/_]\+\)\(.*/'"$NAME"'\.mo$\):%lang(\2) \1\2\3:
 s:^\([^%].*\)::
 '"$ONLY_C"'/%lang(C)/!d
 '"$NO_C"'/%lang(C)/d
 s:%lang(C) ::
 /^$/d' >> $MO_NAME_NEW
 
-find $TOP_DIR -type f -o -type l|sed '
+find $TOP_DIR -type d|sed '
 s:'"$TOP_DIR"'::
-/\/share\/locale\//d
-'"$ALL_NAME$MO"'s:\(.*/locale/\)\([^/_]\+\)\([^/]*\)\(.*\)/LC_MESSAGES/.*\.mo$:%lang(\2) %doc \1\2\3\4:
-'"$NO_ALL_NAME$MO"'s:\(.*/locale/\)\([^/_]\+\)\([^/]*\)\(.*\)/LC_MESSAGES/'"$NAME"'\.mo$:%lang(\2) %doc \1\2\3\4:
+'"$NO_ALL_NAME$GNOME"'s:\(.*/share/help/\)\([^/_]\+\)\([^/]*\)\(/'"$NAME"'\)$:%lang(\2) %doc \1\2\3\4/:
+'"$ALL_NAME$GNOME"'s:\(.*/share/help/\)\([^/_]\+\)\([^/]*\)\(/[a-zA-Z0-9.\_\-]\+\)$:%lang(\2) %doc \1\2\3\4/:
 s:^\([^%].*\)::
+'"$ONLY_C"'/%lang(C)/!d
+'"$NO_C"'/%lang(C)/d
 s:%lang(C) ::
-/^ *$/d' >> $MO_NAME_NEW
+/^$/d' >> $MO_NAME_NEW
 
 find $TOP_DIR -type d|sed '
 s:'"$TOP_DIR"'::
@@ -217,10 +224,10 @@ fi
 
 find $TOP_DIR -type f -o -type l|sed '
 s:'"$TOP_DIR"'::
-'"$NO_ALL_NAME$QT"'s:\(.*/'"$NAME"'_\([a-zA-Z]\{2\}\(_[a-zA-Z]\{2\}\)\?\)\.qm$\):%lang(\2) \1:
-'"$ALL_NAME$QT"'s:\(.*/[^/_]\+_\([a-zA-Z]\{2\}_[a-zA-Z]\{2\}\)\.qm$\):%lang(\2) \1:
+'"$NO_ALL_NAME$QT"'s:\(.*/'"$NAME"'_\([a-zA-Z]\{2\}\([_@].*\)\?\)\.qm$\):%lang(\2) \1:
+'"$ALL_NAME$QT"'s:\(.*/[^/_]\+_\([a-zA-Z]\{2\}[_@].*\)\.qm$\):%lang(\2) \1:
 '"$ALL_NAME$QT"'s:\(.*/[^/_]\+_\([a-zA-Z]\{2\}\)\.qm$\):%lang(\2) \1:
-'"$ALL_NAME$QT"'s:^\([^%].*/[^/]\+_\([a-zA-Z]\{2\}_[a-zA-Z]\{2\}\)\.qm$\):%lang(\2) \1:
+'"$ALL_NAME$QT"'s:^\([^%].*/[^/]\+_\([a-zA-Z]\{2\}[_@].*\)\.qm$\):%lang(\2) \1:
 '"$ALL_NAME$QT"'s:^\([^%].*/[^/]\+_\([a-zA-Z]\{2\}\)\.qm$\):%lang(\2) \1:
 s:^[^%].*::
 '"$ONLY_C"'/%lang(C)/!d
