@@ -1,4 +1,24 @@
 #! /usr/bin/perl -w
+# ------------------------------------------------------------------------------
+# Copyright (c) 2006-2012 Novell, Inc. All Rights Reserved.
+#
+#
+# This program is free software; you can redistribute it and/or modify it under
+# the terms of version 2 of the GNU General Public License as published by the
+# Free Software Foundation.
+#
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License along with
+# this program; if not, contact Novell, Inc.
+#
+# To contact Novell about this file by physical or electronic mail, you may find
+# current contact information at www.novell.com.
+# ------------------------------------------------------------------------------
+#
+
 # File:		modules/UsersPasswd.pm
 # Package:	Configuration of users and groups
 # Summary:	Access to /etc/passwd, /etc/shadow and /etc/group
@@ -68,6 +88,9 @@ my $base_directory	 = "/etc";
 # data correctly initialized ? (Read must be called before Get*)
 my $initialized		= 0;
 
+# indicates that /etc/shadow is missing (may be intentional, see bnc#583338)
+my $no_shadow		= 0;
+
 #---------------------------------------------------------------------
 #-------------------------------------------------- internal functions
 
@@ -100,11 +123,13 @@ sub read_shadow {
     %shadow_tmp	= ();
     @plus_lines_shadow	= ();
     @comments_shadow	= ();
+    $no_shadow	= 0;
 
     my $file	= "$base_directory/shadow";
 
     if (! FileUtils->Exists ($file)) {
 	y2warning ("$file is not available!");
+    	$no_shadow	= 1;
 	return 1;
     }
     my $in	= SCR->Read (".target.string", $file);
@@ -171,6 +196,7 @@ sub read_group {
     %groups	= ();
     %gids	= ();
     %groupnames	= ();
+    %users_groups       = ();
     %groups_by_gidnumber= ();
     @plus_lines_group	= ();
     @comments_group	= ();
@@ -420,6 +446,10 @@ sub read_passwd {
 		"userPassword"	=> undef,
 		"type"		=> $user_type
 	    };
+	    # sometimes real password might be in /etc/passwd
+	    if ($password ne "" && $password ne "x" && $no_shadow) {
+	    	$users{$user_type}{$username}{"userPassword"} = $password;
+	    }
 
 	    if (! defined $shadow_tmp{$username}) {
 		y2debug ("There is no shadow entry for user $username.");
@@ -687,6 +717,10 @@ sub WriteUsers {
 
 	    my %user	= %{$users_w{$type}{$username}};
 	    my $pass	= "x";
+	    if ($no_shadow && $user{"userPassword"})
+	    {
+		$pass	= $user{"userPassword"};
+	    }
 	    my $cn	= $user{"cn"} || "";
 	    if (defined $user{"addit_data"} && $user{"addit_data"} ne "") {
 		$cn	.= ",".$user{"addit_data"};
